@@ -2,8 +2,7 @@ from functools import wraps
 from threading import local
 
 from django.conf import settings
-from django.template import Template
-from django.template.response import TemplateResponse
+from django.http import HttpResponse
 from django.utils import simplejson as json
 
 
@@ -14,7 +13,7 @@ _thread_locals = local()
 class PartialPageMiddleware(object):
 	"""
 	Catches the requests for partial pages and saves all the named blocks in a dictionary, then sends the dictionary as JSON.
-	
+
 	Notes: this middleware will catch the blocks contents at the moment they are rendered, no matter who calls response.render(). But if other middleware classes replace the response contents (say, redirect links to a counter), these changes can't be saved in the dictionary.
 	"""
 	def __init__(self):
@@ -27,6 +26,7 @@ class PartialPageMiddleware(object):
 		# here we stick our nose into block node:
 		# we capture its return value and save it into a dictionary
 		real_render = BlockNode.render
+
 		def new_render(self, context):
 			result = real_render(self, context)
 			if not _thread_locals.request.no_partial and self.name in getattr(_thread_locals.request, 'partials', []):  # save the block contents if it's requested in GET
@@ -44,19 +44,17 @@ class PartialPageMiddleware(object):
 		request.partials = []
 		if not request.no_partial and PARTIAL_PARAM_NAME in request.GET:
 			request.partials = request.GET[PARTIAL_PARAM_NAME].split(',')
-		
+
 		_thread_locals.partial_blocks = {}
 
-	def process_template_response(self, request, response):
+	def process_response(self, request, response):
 		"""
 		Bypasses the response or, if partial page is requested, returns JSON.
 		"""
-		response.render()
-
 		if getattr(request, 'no_partial', False) or len(getattr(request, 'partials', [])) == 0:
 			return response
 
-		new_response = TemplateResponse(request, Template(json.dumps(_thread_locals.partial_blocks)), mimetype='application/json')
+		new_response = HttpResponse(json.dumps(_thread_locals.partial_blocks), mimetype='application/json')
 		new_response.status_code = response.status_code
 		return new_response
 
